# a temporary GUI string reporting file
GUIString = ""
GUISubtypeString = ""